from .station import Station
from .station import StationQuery
#from .stationquery import StationQuery
from .departure import Departure
from .departure import DepartureQuery
#from .departurequery import DepartureQuery
